__init__ — PyProcar 6.2.1 documentation

Skip to main content
`Ctrl`+`K`

# __init__

ElectronicBandStructure.__init__(kpoints: ndarray, bands: ndarray, efermi: float, n_kx: int | None = None, n_ky: int | None = None, n_kz: int | None = None, projected: ndarray | None = None, projected_phase: ndarray | None = None, weights: ndarray | None = None, kpath: KPath | None = None, labels: List | None = None, reciprocal_lattice: ndarray | None = None)